@@ -1,6 +1,6 @@
 #' Return Efficiency Frontier
 #' 
-#' @param x An \code{eval_model_list} object.
+#' @param x An \code{eval_strategy_list} object.
 #'   
 #' @return A vector of model names on the efficiency
 #'   frontier.
@@ -18,23 +18,23 @@ get_frontier <- function(x) {
       x <- dplyr::mutate_(x, .icer = ~ .cost / .effect) %>% 
         dplyr::arrange_(.dots = list(~.icer, ~ .effect))
       
-      bm <- (dplyr::slice(x, 1))$.model_names
-      ebm <- x$.effect[x$.model_names == bm]
+      bm <- (dplyr::slice(x, 1))$.strategy_names
+      ebm <- x$.effect[x$.strategy_names == bm]
       
       x_res <- x %>% dplyr::filter_(
         substitute(.effect > ebm,
                    list(ebm = ebm)))
       
-      c((dplyr::slice(x, 1))$.model_names, f(x_res))
+      c((dplyr::slice(x, 1))$.strategy_names, f(x_res))
     }
   }
   
-  bm <- get_base_model(x)
-  ebm <- x$.effect[x$.model_names == bm]
+  bm <- get_root_strategy(x)
+  ebm <- x$.effect[x$.strategy_names == bm]
   
   c(bm, f(x %>% dplyr::filter_(
     substitute(
-      .model_names != bm & .effect > ebm,
+      .strategy_names != bm & .effect > ebm,
       env = list(bm = bm, ebm = ebm)
     ))))
 }
