@@ -1,6 +1,6 @@
 mod1 <-
   define_strategy(
-    transition_matrix = define_transition(
+    transition = define_transition(
       .5, .5,
       .1, .9
     ),
@@ -16,7 +16,7 @@ mod1 <-
 
 mod2 <-
   define_strategy(
-    transition_matrix = define_transition(
+    transition = define_transition(
       .5, .5,
       .1, .9
     ),
