@@ -18,17 +18,13 @@ test_that(
     ##   instead, we'll check parts that use multi-core processing
     ## 
     ##  parameters from the discrete sensitivity analysis
-    expect_identical(result_1core$dsa$.par_value,
-                     result_2core$dsa$.par_value)
+    expect_identical(result_1core$dsa$dsa$.par_value,
+                     result_2core$dsa$dsa$.par_value)
     ##  counts from all models from the discrete sensitivity analysis
-    expect_identical(lapply(result_1core$dsa$.mod, get_counts),
-                     lapply(result_2core$dsa$.mod, get_counts))
+    expect_identical(get_counts(get_model(result_1core$dsa)),
+                     get_counts(get_model(result_2core$dsa)))
     ## demographic analysis
-    expect_equal(result_1core$demographics,
-                 result_2core$demographics)
-    ## remove attributes (which contain environments)
-    expect_identical(data.frame(result_1core$demographics),
-                     data.frame(result_2core$demographics))
-    
+    expect_equal(result_1core$demographics$updated_model,
+                 result_2core$demographics$updated_model)
   }
 )
